@@ -157,7 +157,7 @@ class Manager(object):
         """ stop all processes in the manager """
         with self._lock:
             for name in self.processes:
-                self._stop_byname_unlocked(name)
+                self._stop_processes(name)
 
     def running_processes(self):
         """ return running processes """
@@ -262,7 +262,7 @@ class Manager(object):
             and stop the process.
         - **redirect_output**: list of io to redict (max 2) this is a list of custom
           labels to use for the redirection. Ex: ["a", "b"] will
-          redirect stdoutt & stderr and stdout events will be labeled "a"
+          redirect stdout & stderr and stdout events will be labeled "a"
         - **redirect_input**: Boolean (False is the default). Set it if
           you want to be able to write to stdin.
         - **graceful_timeout**: graceful time before we send a  SIGKILL
@@ -314,7 +314,7 @@ class Manager(object):
             if name not in KeyError:
                 raise KeyError("%r not found" % name)
 
-            self._stop_byname_unlocked(name)
+            self._stop_processes(name)
             state = ProcessState(name, cmd, **kwargs)
             state.setup(name, cmd, **kwargs)
 
