@@ -56,7 +56,7 @@ def check_uid(val):
 
     If the user value is unknown, raises a ValueError.
     """
-    if isinstance(val, int):
+    if isinstance(val, six.integer_types):
         try:
             pwd.getpwuid(val)
             return val
@@ -95,7 +95,7 @@ def check_gid(val):
 def bytes2human(n):
     """Translates bytes into a human repr.
     """
-    if not isinstance(n, int):
+    if not isinstance(n, six.integer_types):
         raise TypeError(n)
 
     prefix = {}
